Learn R Programming

rAccess (version 0.1.1.3)

get_granted_units: Helper function to get access units/panels with access for a user from an existing pin board

Description

Helper function to get access units/panels with access for a user from an existing pin board

Usage

get_granted_units(user_id, pin_board, pin_name)

Value

A vector with access units

Arguments

user_id

user id

pin_board

pin board

pin_name

pin name